@@ -3,6 +3,7 @@
  * from the sidepanel
  *
  * Copyright (C) 2006 - Jesse van den Kieboom <jesse@icecrew.nl>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +28,6 @@
 #include "pluma-file-browser-store.h"
 #include "pluma-file-bookmarks-store.h"
 #include "pluma-file-browser-view.h"
-#include "pluma-file-browser-marshal.h"
 #include "pluma-file-browser-enum-types.h"
 
 struct _PlumaFileBrowserViewPrivate
@@ -379,8 +379,7 @@ activate_selected_files (PlumaFileBrowserView *view) {
 			g_signal_emit (view, signals[DIRECTORY_ACTIVATED], 0, &iter);
 	}
 
-	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (rows);
+	g_list_free_full (rows, (GDestroyNotify) gtk_tree_path_free);
 }
 
 static void
@@ -877,33 +876,29 @@ pluma_file_browser_view_class_init (PlumaFileBrowserViewClass * klass)
 	    g_signal_new ("error",
 			  G_OBJECT_CLASS_TYPE (object_class),
 			  G_SIGNAL_RUN_LAST,
-			  G_STRUCT_OFFSET (PlumaFileBrowserViewClass,
-					   error), NULL, NULL,
-			  pluma_file_browser_marshal_VOID__UINT_STRING,
+			  G_STRUCT_OFFSET (PlumaFileBrowserViewClass, error),
+			  NULL, NULL, NULL,
 			  G_TYPE_NONE, 2, G_TYPE_UINT, G_TYPE_STRING);
 	signals[FILE_ACTIVATED] =
 	    g_signal_new ("file-activated",
 			  G_OBJECT_CLASS_TYPE (object_class),
 			  G_SIGNAL_RUN_LAST,
-			  G_STRUCT_OFFSET (PlumaFileBrowserViewClass,
-					   file_activated), NULL, NULL,
-			  g_cclosure_marshal_VOID__BOXED,
+			  G_STRUCT_OFFSET (PlumaFileBrowserViewClass, file_activated),
+			  NULL, NULL, NULL,
 			  G_TYPE_NONE, 1, GTK_TYPE_TREE_ITER);
 	signals[DIRECTORY_ACTIVATED] =
 	    g_signal_new ("directory-activated",
 			  G_OBJECT_CLASS_TYPE (object_class),
 			  G_SIGNAL_RUN_LAST,
-			  G_STRUCT_OFFSET (PlumaFileBrowserViewClass,
-					   directory_activated), NULL, NULL,
-			  g_cclosure_marshal_VOID__BOXED,
+			  G_STRUCT_OFFSET (PlumaFileBrowserViewClass, directory_activated),
+			  NULL, NULL, NULL,
 			  G_TYPE_NONE, 1, GTK_TYPE_TREE_ITER);
 	signals[BOOKMARK_ACTIVATED] =
 	    g_signal_new ("bookmark-activated",
 			  G_OBJECT_CLASS_TYPE (object_class),
 			  G_SIGNAL_RUN_LAST,
-			  G_STRUCT_OFFSET (PlumaFileBrowserViewClass,
-					   bookmark_activated), NULL, NULL,
-			  g_cclosure_marshal_VOID__BOXED,
+			  G_STRUCT_OFFSET (PlumaFileBrowserViewClass, bookmark_activated),
+			  NULL, NULL, NULL,
 			  G_TYPE_NONE, 1, GTK_TYPE_TREE_ITER);
 }
 
