@@ -3,6 +3,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2005 - Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -416,7 +417,7 @@ selected_group_changed (GtkComboBox             *combo,
 
 	group_name = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (combo));
 
-	if ((group_name == NULL) || (strlen (group_name) <= 0))
+	if ((group_name == NULL) || (*group_name == '\0'))
 	{
 		g_free (group_name);
 		return;
