@@ -6,6 +6,7 @@
  * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi
  * Copyright (C) 2002-2005 Paolo Maggi
  * Copyright (C) 2011 Perberos
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +33,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+#include <config.h>
 #endif
 
 #include <glib.h>
@@ -64,7 +65,7 @@ void _pluma_cmd_help_about(GtkAction* action, PlumaWindow* window)
 	};
 
 	static const gchar comments[] = \
-		N_("Pluma is a small and lightweight text editor for the MATE Desktop");
+		N_("Pluma is a small and lightweight text editor for the MATE Desktop Environment.");
 
 	static const gchar *license[] ={
 		N_("Pluma is free software; you can redistribute it and/or modify "
@@ -118,14 +119,14 @@ void _pluma_cmd_help_about(GtkAction* action, PlumaWindow* window)
 		               "Copyright \xc2\xa9 2003-2006 Paolo Maggi\n"
 		               "Copyright \xc2\xa9 2004-2010 Paolo Borelli, Jesse van den Kieboom\nSteve Fr\303\251cinaux, Ignacio Casal Quinteiro\n"
 		               "Copyright \xc2\xa9 2011 Perberos\n"
-		               "Copyright \xc2\xa9 2012-2020 MATE developers"),
+		               "Copyright \xc2\xa9 2012-2021 MATE developers"),
 		"license", license_trans,
 		"wrap-license", TRUE,
 		"documenters", documenters,
 		"logo_icon_name", "accessories-text-editor",
 		"translator-credits", _("translator-credits"),
 		"version", VERSION,
-		"website", "http://mate-desktop.org",
+		"website", PACKAGE_URL,
 		NULL);
 
 	g_strfreev (authors);
