@@ -4,6 +4,7 @@
  *
  * Copyright (C) 2008 Ignacio Casal Quinteiro
  * Copyright (C) 2011 Perberos
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,58 +67,3 @@ gchar* pluma_dirs_get_user_accels_file(void)
 
 	return accels;
 }
-
-gchar* pluma_dirs_get_pluma_data_dir(void)
-{
-	return g_build_filename(PLUMA_DATADIR, NULL);
-}
-
-gchar* pluma_dirs_get_pluma_locale_dir(void)
-{
-	return g_build_filename(DATADIR, "locale", NULL);
-}
-
-gchar* pluma_dirs_get_pluma_lib_dir(void)
-{
-	return g_build_filename(LIBDIR, "pluma", NULL);
-}
-
-gchar* pluma_dirs_get_pluma_plugins_dir(void)
-{
-	gchar* lib_dir;
-	gchar* plugin_dir;
-
-	lib_dir = pluma_dirs_get_pluma_lib_dir();
-
-	plugin_dir = g_build_filename(lib_dir, "plugins", NULL);
-	g_free(lib_dir);
-
-	return plugin_dir;
-}
-
-gchar* pluma_dirs_get_pluma_plugins_data_dir(void)
-{
-	gchar* data_dir;
-	gchar* plugin_data_dir;
-
-	data_dir = pluma_dirs_get_pluma_data_dir();
-
-	plugin_data_dir = g_build_filename(data_dir, "plugins", NULL);
-	g_free(data_dir);
-
-	return plugin_data_dir;
-}
-
-gchar* pluma_dirs_get_ui_file(const gchar* file)
-{
-	gchar* datadir;
-	gchar* ui_file;
-
-	g_return_val_if_fail(file != NULL, NULL);
-
-	datadir = pluma_dirs_get_pluma_data_dir();
-	ui_file = g_build_filename(datadir, "ui", file, NULL);
-	g_free(datadir);
-
-	return ui_file;
-}
