@@ -5,6 +5,7 @@
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
  * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi
  * Copyright (C) 2002-2005 Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,7 +41,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include "pluma-prefs-manager-app.h"
+#include "pluma-settings.h"
 #include "pluma-document.h"
 #include "pluma-debug.h"
 #include "pluma-utils.h"
@@ -48,7 +49,6 @@
 #include "pluma-style-scheme-manager.h"
 #include "pluma-document-loader.h"
 #include "pluma-document-saver.h"
-#include "pluma-marshal.h"
 #include "pluma-enum-types.h"
 #include "plumatextregion.h"
 
@@ -76,6 +76,14 @@ PROFILE (static GTimer *timer = NULL)
 #define PLUMA_MAX_PATH_LEN  2048
 #endif
 
+/* undo https://gitlab.gnome.org/GNOME/gtksourceview/-/commit/b3dffc39 */
+#undef GTK_SOURCE_CHECK_VERSION
+#define GTK_SOURCE_CHECK_VERSION(major, minor, micro) \
+        (GTK_SOURCE_MAJOR_VERSION > (major) || \
+        (GTK_SOURCE_MAJOR_VERSION == (major) && GTK_SOURCE_MINOR_VERSION > (minor)) || \
+        (GTK_SOURCE_MAJOR_VERSION == (major) && GTK_SOURCE_MINOR_VERSION == (minor) && \
+         GTK_SOURCE_MICRO_VERSION >= (micro)))
+
 static void	pluma_document_load_real	(PlumaDocument          *doc,
 						 const gchar            *uri,
 						 const PlumaEncoding    *encoding,
@@ -99,6 +107,8 @@ static void	delete_range_cb 		(PlumaDocument *doc,
 
 struct _PlumaDocumentPrivate
 {
+	GSettings   *editor_settings;
+
 	gchar	    *uri;
 	gint 	     untitled_number;
 	gchar       *short_name;
@@ -109,8 +119,8 @@ struct _PlumaDocumentPrivate
 
 	gchar	    *content_type;
 
-	GTimeVal     mtime;
-	GTimeVal     time_of_last_save_or_load;
+	gint64       mtime;
+	gint64       time_of_last_save_or_load;
 
 	guint        search_flags;
 	gchar       *search_text;
@@ -279,6 +289,8 @@ pluma_document_dispose (GObject *object)
 		doc->priv->metadata_info = NULL;
 	}
 
+	g_clear_object (&doc->priv->editor_settings);
+
 	doc->priv->dispose_has_run = TRUE;
 
 	G_OBJECT_CLASS (pluma_document_parent_class)->dispose (object);
@@ -531,8 +543,7 @@ pluma_document_class_init (PlumaDocumentClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaDocumentClass, cursor_moved),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      0);
 
@@ -551,8 +562,7 @@ pluma_document_class_init (PlumaDocumentClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaDocumentClass, load),
-			      NULL, NULL,
-			      pluma_marshal_VOID__STRING_BOXED_INT_BOOLEAN,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      4,
 			      G_TYPE_STRING,
@@ -568,8 +578,7 @@ pluma_document_class_init (PlumaDocumentClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaDocumentClass, loading),
-			      NULL, NULL,
-			      pluma_marshal_VOID__UINT64_UINT64,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      2,
 			      G_TYPE_UINT64,
@@ -580,8 +589,7 @@ pluma_document_class_init (PlumaDocumentClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaDocumentClass, loaded),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_POINTER);
@@ -600,8 +608,7 @@ pluma_document_class_init (PlumaDocumentClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaDocumentClass, save),
-			      NULL, NULL,
-			      pluma_marshal_VOID__STRING_BOXED_FLAGS,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      3,
 			      G_TYPE_STRING,
@@ -615,8 +622,7 @@ pluma_document_class_init (PlumaDocumentClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaDocumentClass, saving),
-			      NULL, NULL,
-			      pluma_marshal_VOID__UINT64_UINT64,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      2,
 			      G_TYPE_UINT64,
@@ -627,8 +633,7 @@ pluma_document_class_init (PlumaDocumentClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaDocumentClass, saved),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_POINTER);
@@ -638,14 +643,14 @@ pluma_document_class_init (PlumaDocumentClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaDocumentClass, search_highlight_updated),
-			      NULL, NULL,
-			      pluma_marshal_VOID__BOXED_BOXED,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      2,
 			      GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE,
 			      GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE);
 }
 
+#if !GTK_SOURCE_CHECK_VERSION(4, 3, 1)
 static gboolean
 file_with_bom (GFile *file)
 {
@@ -688,6 +693,7 @@ file_with_bom (GFile *file)
 	else
 		return FALSE;
 }
+#endif
 
 static void
 set_language (PlumaDocument     *doc,
@@ -695,7 +701,15 @@ set_language (PlumaDocument     *doc,
               gboolean           set_by_user)
 {
 	GtkSourceLanguage *old_lang;
-	const gchar       *bom_langs;
+
+#if !GTK_SOURCE_CHECK_VERSION(4, 3, 1)
+	const gchar       *new_lang_id;
+	const gchar       *bom_langs[] = {
+		"asp", "dtl", "docbook", "html", "mxml", "mallard", "markdown",
+		"mediawiki", "php", "tera", "xml", "xslt", NULL
+	};
+	gboolean is_bom_lang = FALSE;
+#endif
 
 	pluma_debug (DEBUG_DOCUMENT);
 
@@ -704,24 +718,40 @@ set_language (PlumaDocument     *doc,
 	if (old_lang == lang)
 		return;
 
-	bom_langs = "asp,dtl,docbook,html,mxml,mallard,markdown,mediawiki,php,tera,xml,xslt";
+#if !GTK_SOURCE_CHECK_VERSION(4, 3, 1)
+	new_lang_id = gtk_source_language_get_id (lang);
+	if (new_lang_id)
+		is_bom_lang = g_strv_contains (bom_langs, new_lang_id);
 
-	if (g_strrstr (bom_langs, gtk_source_language_get_id (lang)))
+	if (is_bom_lang)
 	{
 		GFile *file;
+
 		file = pluma_document_get_location (doc);
+		if (file)
+		{
+			if (!file_with_bom (file))
+				gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (doc), lang);
 
-		if (!file_with_bom (file))
+			g_object_unref (file);
+		}
+		else
 			gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (doc), lang);
-
-		g_object_unref (file);
 	}
 	else
+#endif
 		gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (doc), lang);
 
 	if (lang != NULL)
+	{
+		gboolean syntax_hl;
+
+		syntax_hl = g_settings_get_boolean (doc->priv->editor_settings,
+						    PLUMA_SETTINGS_SYNTAX_HIGHLIGHTING);
+
 		gtk_source_buffer_set_highlight_syntax (GTK_SOURCE_BUFFER (doc),
-				 pluma_prefs_manager_get_enable_syntax_highlighting ());
+							syntax_hl);
+	}
 	else
 		gtk_source_buffer_set_highlight_syntax (GTK_SOURCE_BUFFER (doc),
 				 FALSE);
@@ -764,14 +794,14 @@ set_encoding (PlumaDocument       *doc,
 }
 
 static GtkSourceStyleScheme *
-get_default_style_scheme (void)
+get_default_style_scheme (GSettings *editor_settings)
 {
 	gchar *scheme_id;
 	GtkSourceStyleScheme *def_style;
 	GtkSourceStyleSchemeManager *manager;
 
 	manager = pluma_get_style_scheme_manager ();
-	scheme_id = pluma_prefs_manager_get_source_style_scheme ();
+	scheme_id = g_settings_get_string (editor_settings, PLUMA_SETTINGS_COLOR_SCHEME);
 	def_style = gtk_source_style_scheme_manager_get_scheme (manager,
 								scheme_id);
 
@@ -918,11 +948,16 @@ static void
 pluma_document_init (PlumaDocument *doc)
 {
 	GtkSourceStyleScheme *style_scheme;
+	gint undo_actions;
+	gboolean bracket_matching;
+	gboolean search_hl;
 
 	pluma_debug (DEBUG_DOCUMENT);
 
 	doc->priv = pluma_document_get_instance_private (doc);
 
+	doc->priv->editor_settings = g_settings_new (PLUMA_SCHEMA_ID);
+
 	doc->priv->uri = NULL;
 	doc->priv->untitled_number = get_untitled_number ();
 
@@ -939,25 +974,31 @@ pluma_document_init (PlumaDocument *doc)
 
 	doc->priv->dispose_has_run = FALSE;
 
-	doc->priv->mtime.tv_sec = 0;
-	doc->priv->mtime.tv_usec = 0;
+	doc->priv->mtime = 0;
 
-	g_get_current_time (&doc->priv->time_of_last_save_or_load);
+	doc->priv->time_of_last_save_or_load = g_get_real_time ();
 
 	doc->priv->encoding = pluma_encoding_get_utf8 ();
 
 	doc->priv->newline_type = PLUMA_DOCUMENT_NEWLINE_TYPE_DEFAULT;
 
+	undo_actions = g_settings_get_uint (doc->priv->editor_settings, PLUMA_SETTINGS_MAX_UNDO_ACTIONS);
+
+	bracket_matching = g_settings_get_boolean (doc->priv->editor_settings,
+						   PLUMA_SETTINGS_BRACKET_MATCHING);
+	search_hl = g_settings_get_boolean (doc->priv->editor_settings,
+					    PLUMA_SETTINGS_SEARCH_HIGHLIGHTING);
+
 	gtk_source_buffer_set_max_undo_levels (GTK_SOURCE_BUFFER (doc),
-					       pluma_prefs_manager_get_undo_actions_limit ());
+					       undo_actions);
 
 	gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (doc),
-							   pluma_prefs_manager_get_bracket_matching ());
+							   bracket_matching);
 
-	pluma_document_set_enable_search_highlighting (doc,
-						       pluma_prefs_manager_get_enable_search_highlighting ());
+	pluma_document_set_enable_search_highlighting (doc, search_hl);
 
-	style_scheme = get_default_style_scheme ();
+
+	style_scheme = get_default_style_scheme (doc->priv->editor_settings);
 	if (style_scheme != NULL)
 		gtk_source_buffer_set_style_scheme (GTK_SOURCE_BUFFER (doc),
 						    style_scheme);
@@ -1270,10 +1311,11 @@ _pluma_document_check_externally_modified (PlumaDocument *doc)
 
 	gfile = g_file_new_for_uri (doc->priv->uri);
 	info = g_file_query_info (gfile,
-				  G_FILE_ATTRIBUTE_TIME_MODIFIED "," \
-				  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE,
-				  G_FILE_QUERY_INFO_NONE,
-				  NULL, NULL);
+	                          G_FILE_ATTRIBUTE_TIME_MODIFIED "," \
+	                          G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC "," \
+	                          G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE,
+	                          G_FILE_QUERY_INFO_NONE,
+	                          NULL, NULL);
 	g_object_unref (gfile);
 
 	if (info != NULL)
@@ -1291,14 +1333,20 @@ _pluma_document_check_externally_modified (PlumaDocument *doc)
 
 		if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_TIME_MODIFIED))
 		{
-			GTimeVal timeval;
+			guint64 timeval;
 
-			g_file_info_get_modification_time (info, &timeval);
+			timeval = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_TIME_MODIFIED) * G_USEC_PER_SEC;
+			if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC))
+			{
+				guint32 usec;
+
+				usec = g_file_info_get_attribute_uint32 (info,
+				                                         G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC);
+				timeval += (guint64) usec;
+			}
 			g_object_unref (info);
 
-			return (timeval.tv_sec > doc->priv->mtime.tv_sec) ||
-			       (timeval.tv_sec == doc->priv->mtime.tv_sec &&
-			       timeval.tv_usec > doc->priv->mtime.tv_usec);
+			return (((gint64) timeval) > doc->priv->mtime);
 		}
 	}
 
@@ -1328,9 +1376,10 @@ document_loader_loaded (PlumaDocumentLoader *loader,
 	{
 		GtkTextIter iter;
 		GFileInfo *info;
+		gboolean restore_cursor;
 		const gchar *content_type = NULL;
 		gboolean read_only = FALSE;
-		GTimeVal mtime = {0, 0};
+		guint64 mtime = 0;
 
 		info = pluma_document_loader_get_info (loader);
 
@@ -1341,18 +1390,28 @@ document_loader_loaded (PlumaDocumentLoader *loader,
 										 G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE);
 
 			if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_TIME_MODIFIED))
-				g_file_info_get_modification_time (info, &mtime);
+				mtime = g_file_info_get_attribute_uint64 (info,
+				                                          G_FILE_ATTRIBUTE_TIME_MODIFIED) * G_USEC_PER_SEC;
+
+			if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC))
+			{
+				guint32 usec;
+
+				usec = g_file_info_get_attribute_uint32 (info,
+				                                         G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC);
+				mtime += (guint64) usec;
+			}
 
 			if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE))
 				read_only = !g_file_info_get_attribute_boolean (info,
 										G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
 		}
 
-		doc->priv->mtime = mtime;
+		doc->priv->mtime = (gint64) mtime;
 
 		set_readonly (doc, read_only);
 
-		g_get_current_time (&doc->priv->time_of_last_save_or_load);
+		doc->priv->time_of_last_save_or_load = g_get_real_time ();
 
 		set_encoding (doc,
 			      pluma_document_loader_get_encoding (loader),
@@ -1363,6 +1422,9 @@ document_loader_loaded (PlumaDocumentLoader *loader,
 		pluma_document_set_newline_type (doc,
 		                                 pluma_document_loader_get_newline_type (loader));
 
+		restore_cursor = g_settings_get_boolean (doc->priv->editor_settings,
+							 PLUMA_SETTINGS_RESTORE_CURSOR_POSITION);
+
 		/* move the cursor at the requested line if any */
 		if (doc->priv->requested_line_pos > 0)
 		{
@@ -1372,7 +1434,7 @@ document_loader_loaded (PlumaDocumentLoader *loader,
 							  doc->priv->requested_line_pos - 1);
 		}
 		/* else, if enabled, to the position stored in the metadata */
-		else if (pluma_prefs_manager_get_restore_cursor_position ())
+		else if (restore_cursor)
 		{
 			gchar *pos;
 			gint offset;
@@ -1545,7 +1607,7 @@ document_saver_saving (PlumaDocumentSaver *saver,
 		{
 			const gchar *uri;
 			const gchar *content_type = NULL;
-			GTimeVal mtime = {0, 0};
+			guint64 mtime = 0;
 			GFileInfo *info;
 
 			uri = pluma_document_saver_get_uri (saver);
@@ -1560,13 +1622,23 @@ document_saver_saving (PlumaDocumentSaver *saver,
 											 G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE);
 
 				if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_TIME_MODIFIED))
-					g_file_info_get_modification_time (info, &mtime);
+					mtime = g_file_info_get_attribute_uint64 (info,
+					                                          G_FILE_ATTRIBUTE_TIME_MODIFIED) * G_USEC_PER_SEC;
+
+				if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC))
+				{
+					guint32 usec;
+
+					usec = g_file_info_get_attribute_uint32 (info,
+					                                         G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC);
+					mtime += (guint64) usec;
+				}
 			}
 
 			set_content_type (doc, content_type);
-			doc->priv->mtime = mtime;
+			doc->priv->mtime = (gint64) mtime;
 
-			g_get_current_time (&doc->priv->time_of_last_save_or_load);
+			doc->priv->time_of_last_save_or_load = g_get_real_time ();
 
 			_pluma_document_set_readonly (doc, FALSE);
 
@@ -2314,15 +2386,11 @@ pluma_document_get_encoding (PlumaDocument *doc)
 glong
 _pluma_document_get_seconds_since_last_save_or_load (PlumaDocument *doc)
 {
-	GTimeVal current_time;
-
 	pluma_debug (DEBUG_DOCUMENT);
 
 	g_return_val_if_fail (PLUMA_IS_DOCUMENT (doc), -1);
 
-	g_get_current_time (&current_time);
-
-	return (current_time.tv_sec - doc->priv->time_of_last_save_or_load.tv_sec);
+	return ((g_get_real_time () - doc->priv->time_of_last_save_or_load) / G_USEC_PER_SEC);
 }
 
 static void
