@@ -3,6 +3,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2005 - Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,16 +47,16 @@
 #include "pluma-notebook.h"
 #include "pluma-tab.h"
 #include "pluma-tab-label.h"
-#include "pluma-marshal.h"
 #include "pluma-window.h"
-#include "pluma-prefs-manager.h"
-#include "pluma-prefs-manager-private.h"
+#include "pluma-settings.h"
 
 #define AFTER_ALL_TABS -1
 #define NOT_IN_APP_WINDOWS -2
 
 struct _PlumaNotebookPrivate
 {
+	GSettings     *editor_settings;
+
 	GList         *focused_pages;
 	gulong         motion_notify_handler_id;
 	gint           x_start;
@@ -68,8 +69,6 @@ struct _PlumaNotebookPrivate
 
 G_DEFINE_TYPE_WITH_PRIVATE (PlumaNotebook, pluma_notebook, GTK_TYPE_NOTEBOOK)
 
-static void pluma_notebook_finalize (GObject *object);
-
 static gboolean pluma_notebook_change_current_page (GtkNotebook *notebook,
 						    gint         offset);
 
@@ -97,6 +96,16 @@ enum
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
+static void
+pluma_notebook_finalize (GObject *object)
+{
+	PlumaNotebook *notebook = PLUMA_NOTEBOOK (object);
+
+	g_list_free (notebook->priv->focused_pages);
+
+	G_OBJECT_CLASS (pluma_notebook_parent_class)->finalize (object);
+}
+
 static void
 pluma_notebook_dispose (GObject *object)
 {
@@ -118,6 +127,8 @@ pluma_notebook_dispose (GObject *object)
 		notebook->priv->destroy_has_run = TRUE;
 	}
 
+	g_clear_object (&notebook->priv->editor_settings);
+
 	G_OBJECT_CLASS (pluma_notebook_parent_class)->dispose (object);
 }
 
@@ -137,8 +148,7 @@ pluma_notebook_class_init (PlumaNotebookClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (PlumaNotebookClass, tab_added),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__OBJECT,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      PLUMA_TYPE_TAB);
@@ -147,8 +157,7 @@ pluma_notebook_class_init (PlumaNotebookClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (PlumaNotebookClass, tab_removed),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__OBJECT,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      PLUMA_TYPE_TAB);
@@ -157,8 +166,7 @@ pluma_notebook_class_init (PlumaNotebookClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (PlumaNotebookClass, tab_detached),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__OBJECT,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      PLUMA_TYPE_TAB);
@@ -167,8 +175,7 @@ pluma_notebook_class_init (PlumaNotebookClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (PlumaNotebookClass, tabs_reordered),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      0);
 	signals[TAB_CLOSE_REQUEST] =
@@ -176,8 +183,7 @@ pluma_notebook_class_init (PlumaNotebookClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaNotebookClass, tab_close_request),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__OBJECT,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      PLUMA_TYPE_TAB);
@@ -786,13 +792,15 @@ update_tabs_visibility (PlumaNotebook *nb)
 
 	num = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
 
-	show_tabs = (g_settings_get_boolean (pluma_prefs_manager->settings, "show-single-tab") || num > 1);
+	show_tabs = (g_settings_get_boolean (nb->priv->editor_settings, PLUMA_SETTINGS_SHOW_SINGLE_TAB) || (num > 1));
 
-	if (g_settings_get_boolean (pluma_prefs_manager->settings, "show-tabs-with-side-pane"))
+	if (g_settings_get_boolean (nb->priv->editor_settings, PLUMA_SETTINGS_SHOW_TABS_WITH_SIDE_PANE))
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), show_tabs);
 	else
 	{
-		if (pluma_prefs_manager_get_side_pane_visible ())
+		gboolean visible = g_settings_get_boolean (nb->priv->editor_settings, PLUMA_SETTINGS_SIDE_PANE_VISIBLE);
+
+		if (visible)
 			gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), FALSE);
 		else
 			gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), show_tabs);
@@ -804,6 +812,8 @@ pluma_notebook_init (PlumaNotebook *notebook)
 {
 	notebook->priv = pluma_notebook_get_instance_private (notebook);
 
+	notebook->priv->editor_settings = g_settings_new (PLUMA_SCHEMA_ID);
+
 	notebook->priv->close_buttons_sensitive = TRUE;
 	notebook->priv->tab_drag_and_drop_enabled = TRUE;
 
@@ -845,16 +855,6 @@ pluma_notebook_init (PlumaNotebook *notebook)
                                 NULL);
 }
 
-static void
-pluma_notebook_finalize (GObject *object)
-{
-	PlumaNotebook *notebook = PLUMA_NOTEBOOK (object);
-
-	g_list_free (notebook->priv->focused_pages);
-
-	G_OBJECT_CLASS (pluma_notebook_parent_class)->finalize (object);
-}
-
 /*
  * We need to override this because when we don't show the tabs, like in
  * fullscreen we need to have wrap around too
