@@ -3,6 +3,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2002-2005 Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,8 +41,8 @@
 #include "pluma-plugins-engine.h"
 #include "pluma-debug.h"
 #include "pluma-app.h"
-#include "pluma-prefs-manager.h"
 #include "pluma-dirs.h"
+#include "pluma-settings.h"
 
 struct _PlumaPluginsEnginePrivate
 {
@@ -55,7 +56,6 @@ PlumaPluginsEngine *default_engine = NULL;
 static void
 pluma_plugins_engine_init (PlumaPluginsEngine *engine)
 {
-	gchar *private_path;
 	GError *error = NULL;
 
 	pluma_debug (DEBUG_PLUGINS);
@@ -64,47 +64,41 @@ pluma_plugins_engine_init (PlumaPluginsEngine *engine)
 
 	engine->priv = pluma_plugins_engine_get_instance_private (engine);
 
-	engine->priv->plugin_settings = g_settings_new (PLUMA_SCHEMA);
+	engine->priv->plugin_settings = g_settings_new (PLUMA_SCHEMA_ID);
 
 	/* This should be moved to libpeas */
 	if (!g_irepository_require (g_irepository_get_default (),
 	                            "Peas", "1.0", 0, &error))
 	{
 		g_warning ("Could not load Peas repository: %s", error->message);
-		g_error_free (error);
-		error = NULL;
+		g_clear_error (&error);
 	}
 
 	if (!g_irepository_require (g_irepository_get_default (),
 	                            "PeasGtk", "1.0", 0, &error))
 	{
 		g_warning ("Could not load PeasGtk repository: %s", error->message);
-		g_error_free (error);
-		error = NULL;
+		g_clear_error (&error);
 	}
 
-	private_path = g_build_filename (LIBDIR, "girepository-1.0", NULL);
-
 	if (!g_irepository_require_private (g_irepository_get_default (),
-	                                    private_path, "Pluma", "1.0", 0, &error))
+	                                    LIBDIR "/girepository-1.0",
+	                                    "Pluma", "1.0", 0, &error))
 	{
 		g_warning ("Could not load Pluma repository: %s", error->message);
-		g_error_free (error);
-		error = NULL;
+		g_clear_error (&error);
 	}
 
-	g_free (private_path);
-
 	peas_engine_add_search_path (PEAS_ENGINE (engine),
 	                             pluma_dirs_get_user_plugins_dir (),
 	                             pluma_dirs_get_user_plugins_dir ());
 
 	peas_engine_add_search_path (PEAS_ENGINE (engine),
-	                             pluma_dirs_get_pluma_plugins_dir (),
-	                             pluma_dirs_get_pluma_plugins_data_dir ());
+	                             PLUMA_LIBDIR "/plugins",
+	                             PLUMA_DATADIR "/plugins");
 
 	g_settings_bind (engine->priv->plugin_settings,
-	                 GPM_ACTIVE_PLUGINS,
+	                 PLUMA_SETTINGS_ACTIVE_PLUGINS,
 	                 engine,
 	                 "loaded-plugins",
 	                 G_SETTINGS_BIND_DEFAULT);
