@@ -3,6 +3,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2005 - Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,8 +35,8 @@
 #include <libpeas/peas-extension-set.h>
 
 #include "pluma/pluma-window.h"
-#include "pluma-prefs-manager.h"
 #include "pluma-message-bus.h"
+#include "pluma-settings.h"
 
 G_BEGIN_DECLS
 
@@ -43,6 +44,8 @@ G_BEGIN_DECLS
 
 struct _PlumaWindowPrivate
 {
+	GSettings      *editor_settings;
+
 	GtkWidget      *notebook;
 
 	GtkWidget      *side_panel;
